<?php
/**
 *
 * Function Theme: MiniSense
 *
 * @version 1.0
 * @package Minisense
 *
 * Minisense Theme initializer
*/
// prevent direct access
if( !defined( 'ABSPATH' ) ) {
	wp_die();
}
/**
 * define a constant variable
*/
if( !defined( 'MS_THEME_DIRECTORY' ) ) {
	define( 'MS_THEME_DIRECTORY', get_stylesheet_directory() . '/' );
}
/**
 * include admin options
*/
include( MS_THEME_DIRECTORY . '/admin/index.php' );
/**
 * include customizer
*/
include( MS_THEME_DIRECTORY . '/includes/customizer.php' );
/**
 * Minisense Theme Setup
*/
function ms_theme_setup() {
	/**
	 * add theme support
	*/
	if( function_exists( 'add_theme_support' ) ) {
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'title-tag' );
	}
	/**
	 * add image size
	*/
	if( function_exists( 'add_image_size' ) ) {
		add_image_size( 'mini-thumbnail', 85, 62, true );
	}
	/**
	 * register navigation menue
	*/
	register_nav_menus( array(
		'navigation'	=>	'Navigation',
		'top-menu'		=>	'Top Menu'
	) );
}
add_action( "after_setup_theme", "ms_theme_setup" );
/**
 * Widgets init */
function ms_widgets_init() {
	register_sidebar( array(
		'id'			=>	'main-sidebar',
		'name'			=>	'Main Sidebar',
		'before_widget'	=>	'<div class="widget %2$s" id="%1$s">',
		'after_widget'	=>	'</div>',
		'before_title'	=>	'<h2 class="title widget-title">',
		'after_title'	=>	'</h2>'
	) );
	register_sidebar( array(
		'id'			=>	'footer-widgets',
		'name'			=>	'Footer widgets',
		'before_widget'	=>	'<div class="widget %2$s" id="%1$s">',
		'after_widget'	=>	'</div>',
		'before_title'	=>	'<h2 class="title widget-title">',
		'after_title'	=>	'</h2>'
	) );
}
add_action( "widgets_init", "ms_widgets_init" );
/**
 * custom post class
*/
function ms_custom_post_class( $classes ) {
	$classes[] = 'post-entry';
	return $classes;
}
add_filter( "post_class", "ms_custom_post_class" );
/**
 * enqueue styles
*/
function ms_styles() {
	if( ! is_admin() ) {
		wp_register_style( 'normalize', get_stylesheet_directory_uri() . '/css/normalize.css' );
		wp_register_style( 'minisense-style', get_stylesheet_uri() );
		wp_enqueue_style( array( 'normalize', 'minisense-style' ) );
		global $data;
		if ( isset( $data['ms_custom_css'] ) && ! empty( $data['ms_custom_css'] ) ) {
			wp_add_inline_style( 'minisense-style', $data['ms_custom_css'] );
		}
	}
}
add_action( "wp_enqueue_scripts", "ms_styles" );
/**
 * Preview the changes
*/
function ms_enqueue_customized_script() {
	$background_color = get_theme_mod( 'ms_background_color', '#2cbcea' );
	$background_image = get_theme_mod( 'ms_background_image', '' );
	if ( ! empty( $background_image ) ) {
		$background_image = str_replace( '[site_url]', home_url('/'), $background_image );
		$background_image = 'background-image:url(' . $background_image . ');background-position: center; background-attachment: fixed; background-size: cover;';
	}
	$background_nav = get_theme_mod( 'ms_navigation_background_color', '#49ad49' );
	$background_topmenu = get_theme_mod( 'ms_topmenu_background_color', '#353535' );
	$navigation_font_color = get_theme_mod( 'ms_navigation_font_color', '#ffffff' );
	$navigation_font_color_hover = get_theme_mod( 'ms_navigation_font_color_hover', '#ffffff' );
	$topmenu_font_color = get_theme_mod( 'ms_topmenu_font_color', '#ffffff' );
	$topmenu_font_color_hover = get_theme_mod( 'ms_topmenu_font_color_hover', '#ffffff' );
	$link_color = get_theme_mod( 'ms_link_color', '#428bca' );
	$link_color_hover = get_theme_mod( 'ms_link_color_hover', '#428bca' );
	$base_color = get_theme_mod( 'ms_font_color', '#848484' );
	$css = " body { background-color: {$background_color};{$background_image}  }
			p, small, span, attr, blockquote, caption, button, div, strong, i, u { color: {$base_color} }
			 a { color: {$link_color} }
			 .widget a { color:{$base_color} }
			 a:hover { color: {$link_color_hover} }
			 .navigation { background-color: {$background_nav}; }
			 .topmenu { background-color: {$background_topmenu} }
			 .topmenu ul li a { color:{$topmenu_font_color} }
			 .topmenu ul li a:hover { color: {$topmenu_font_color_hover} }
			 .navigation ul li a { color: {$navigation_font_color} }
			 .navigation ul li a:hover { color: {$navigation_font_color_hover} }";
	wp_add_inline_style( 'minisense-style', $css );
}
add_action( "wp_enqueue_scripts", "ms_enqueue_customized_script" );
/**
 * breadcrumbs
*/
function ms_build_breadcrumbs( array $args = null ) {
	$args = wp_parse_args( $args, array(
				'homepage' => '<a href="%s"><strong>%s</strong></a>',
				'categories' => '<a href="%s"><strong>%s</strong></a>',
				'post' => '<i>%s</i>',
				'separator' => '&nbsp;/&nbsp;'
	) );
	// set breadcrumbs
	$breadcrumbs = array();
	// set up homepage links
	$breadcrumbs[] = sprintf( $args['homepage'], home_url(), 'Home' );
	// set up categories links
	$cats = get_the_category();
	if( $cats ) {
		foreach( $cats as $cat ) {
			$breadcrumbs[] .= sprintf( $args['categories'], esc_url( get_term_link( $cat->term_id, 'category' ) ), $cat->name );
		}
	}
	// set post name
	$breadcrumbs[] = sprintf( $args['post'], get_the_title() );
	// set separator
	$breadcrumbs['separator'] = $args['separator'];
	return $breadcrumbs;
}
/**
 * print breadcrumbs
*/
function ms_breadcrumbs( $separator = '&nbsp;->&nbsp;' ) {
	// return if not single post
	if ( ! is_single() )
		return;
	$breadcrumbs = ms_build_breadcrumbs( array( 'separator' => $separator ) );
	// set separator into implode string
	$separator = $breadcrumbs['separator'];
	unset( $breadcrumbs['separator'] );
	echo implode( $separator, array_filter( $breadcrumbs ) );
}
/**
 * thumbnail function
*/
function ms_thumbnail_data( $sizes = 'thumbnail' ) {
	global $post;
	if( !isset( $post->ID ) || $post->ID === 0 )
		return;
	// set default sizes
	if( empty( $sizes ) ) {
		$sizes = 'mini';
	}
	// get image sources
	$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), $sizes );
	// return into image data
	if( isset( $image[0] ) ) {
		/**
		 * add an alt to image data
		*/
		if( get_post_meta( get_post_thumbnail_id( $post->ID ), '_wp_attachment_image_alt', true ) && '' !== get_post_meta( get_post_thumbnail_id( $post->ID ) , '_wp_attachment_image_alt', true ) ) {
			$image['alt-text'] = stripslashes( get_post_meta( get_post_thumbnail_id( $post->ID ), '_wp_attachment_image_alt', true ) );
		}
		return $image;
	}
	return false;
}
/**
 * get thumbnails
*/
function ms_get_thumbnail( $sizes, $classes = array( 'thumbnail' ), $img_width = false, $img_height = false, $img_crop = false ) {
	global $data;
	// get sources
	$image_data = ms_thumbnail_data( $sizes );
	// return if sources returned to false boolean
	if( !$image_data )
		return;
	// set image attribute
	$attr = array();
	$attr['width'] = $img_width !== false ? (float) $img_width : null;
	$attr['height'] = $img_height !== false ? (float) $img_height : null;
	$attr['alt'] = isset( $image_data['alt-text'] ) ? $image_data['alt-text'] : null;
	if ( is_string( $classes ) ) $classes = array( $classes );
	$attr['class'] = implode( ' ', $classes );
	$image_url = esc_url( $image_data[0] );
	$attr['src'] = $image_url;
	// clean attribute
	$attr = array_filter( $attr );
	$create_attribute = array_walk( $attr ,  function( &$val, $key ) {
							$val = $key . '="' . $val . '"';
			  			} );
	if( $create_attribute ) {
		return '<img ' . implode( ' ', $attr ) . '/>';
	} else {
		return '<img src="' . $image_url . '" />';
	}
}
/**
 * print thumbnails
*/
function ms_print_thumbnail( $sizes, $classes = array( 'thumbnail' ), $width = false, $height = false, $crop = false ) {
	echo ms_get_thumbnail( $sizes, $classes, $width, $height, $crop );
}
/**
 * add thumbnail image into single post
*/
/*
function ms_single_content_thumbnail( $content ) {
	if ( is_single() ) {
		if( has_post_thumbnail() ) {
			$image =  '<div class="thumbnail-image single-image">';
			$image .= ms_get_thumbnail( 'full', array( 'single-thumbnail', 'single-left-image' ) );
			$image .= '</div>';
			$content = $image . $content;
		}
	}
	return $content;
}
add_filter( "the_content", "ms_single_content_thumbnail" ); */
/**
 * Ms post data
*/
function ms_post_info( $structure = null ) {
	global $post;
	if ( ! $structure ) {
		$structure = __( 'Post by <a href="%3$s" rel="archive">%1$s</a> on <span itemprop="datePublished">%2$s</span>' );
	}
	$author = get_the_author_meta( 'display_name' );
	$author_url = esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) );
	$date = get_the_date();
	printf( $structure, esc_attr( $author ), $date, $author_url );
}
/**
 * ms related posts
*/
function ms_related_posts( $post_id = null ) {
	if ( ! $post_id ) {
		global $post;
		$post_id = $post->ID;
	}
	$related_by_tags = get_the_tags();
	$related_by_cats = get_the_category();
	if ( $related_by_cats ) {
		$cats_id = array();
		foreach( $related_by_cats as $cat ) {
			$cats_id[] = $cat->term_id;
		}
	}
	if ( $related_by_tags ) {
		$tags_id = array();
		foreach( $related_by_tags as $tag ) {
			$tags_id[] = $tag->term_id;
		}
	}
	$post_not_in = array( $post_id );
	$related_query = array(
			'post_type'			=>	'post',
			'post_status'		=>	'publish',
			'posts_per_page'	=>	6,
			'post__not_in'		=>	$post_not_in,
			'tax_query'			=>	array( 'relation' => 'OR' )
	);
	if ( isset( $cats_id ) ) {
		$related_query['tax_query'][] = array(
				'taxonomy'		=>	'category',
				'field'			=>	'term_id',
				'terms'			=>	$cats_id,
				'compare'		=>	'IN'
		);
	}
	if ( isset( $tags_id ) ) {
		$related_query['tax_query'][] = array(
				'taxomomy'		=>	'post_tag',
				'field'			=>	'term_id',
				'terms'			=>	$tags_id,
				'compare'		=>	'IN'
		);
	}
	$related_posts = array( 
			sprintf( '<div class="%2$s" id="%1$s"><h2 class="related-title">%3$s</h2>', 'related-posts-with-' . get_the_ID(), 'related-posts', 'Related posts with "' . get_the_title() . '"' )
	 );
	$query_object = new WP_Query( $related_query );
	if ( $query_object->have_posts() ) {
		while( $query_object->have_posts() ) {
			$query_object->the_post();
			$related_posts[] = sprintf(
					'<li id="post-%1$s" %2$s>%5$s<a href="%3$s">%4$s</a></li>',
					get_the_ID(), 'class="' . join( ' ', get_post_class( '', get_the_ID() ) ) . '"', get_the_permalink(), get_the_title(),
					ms_get_thumbnail( 'mini-thumbnail', array( 'mini-thumbnail' ) )
			);
		}
		wp_reset_postdata();
	} else {
		unset( $related_posts );
	}
	if ( isset( $related_posts ) ) {
		$related_posts[] = '</div>';
		echo implode( '', $related_posts );
	} else {
		echo '';
	}
}
/**
 * Ms copyright
*/
function ms_copyright() {
	global $data;
	$structure = 'Copyright &copy; %1$s <a href="%2$s" rel="home">%3$s</a>';
	if ( isset( $data['ms_copyright_structure'] ) && ! empty( $data['ms_copyright_structure'] ) ) {
		$structure = $data['ms_copyright_structure'];
		$structure = str_replace( '[year]', '%1$s', $structure );
		$structure = str_replace( '[sitelink]', '%2$s', $structure );
		$structure = str_replace( '[sitename]', '%$3s', $structure ); 
	}
	printf( $structure, date('Y'), home_url('/'), get_option('blogname') );
}
/**
 * ms post tags
*/
function ms_post_tags( $html = '' ) {
	$tags = get_the_tags();
	if ( $tags ) {
		$html .= '<ul class="tag-list">';
		$tag_arr = array();
		foreach( $tags as $tag ) {
			$tag_arr[] = sprintf( '<li class="tag-%2$s" id="tag-no-%1$s"><a href="%3$s">%4$s</a></li>', 
								$tag->slug, $tag->term_id, get_term_link( $tag->term_id, 'post_tag' ), $tag->name );
		}
		$html .= implode( ', ', $tag_arr ) . '</ul>';
	}
	if ( isset( $html ) ) echo $html;
}
/**
 * ms post cats
*/
function ms_post_cats( $html = '' ) {
	$cats = get_the_category();
	if ( $cats ) {
		$html .= '<ul class="category-list">';
		$cat_arr = array();
		foreach( $cats as $cat ) {
			$cat_arr[] = sprintf( '<li class="category-%2$s" id="cat-no-%1$s"><a href="%3$s">%4$s</a></li>', 
								$cat->slug, $cat->term_id, get_term_link( $cat->term_id, 'category' ), $cat->name );
		}
		$html .= implode( ', ', $cat_arr ) . '</ul>';
	}
	if ( isset( $html ) ) echo $html;
}

/**
 * insert closing tag of p
 */
function ms_insert_p_closing( $value ) {
	return $value . ' </p>';
}
/**
 * Insert ads into pharagraph 
*/
function ms_insert_ads_to_pharagraph( $adscode, $content ) {
	$closing_p = '</p>';
	$paragraphs = explode( $closing_p, $content );

	if ( count( $paragraphs ) < 2 ) {
		return $content;
	}

	$middle = floor( count( $paragraphs ) / 2 );
	foreach ($paragraphs as $index => $paragraph) {
		if ( trim( $paragraph ) ) {
			$paragraphs[$index] .= $closing_p;
		}

		if ( $middle == $index + 1 ) {
			$paragraphs[$index] .= $adscode;
		}
	}
	return implode( '', $paragraphs );
}
function ads_insertion( $content ) {
	if ( ! is_single() ) {
		return $content;
	}
	global $data;
	$adscode = isset( $data['enable_ads_on_pharagraph'] ) ? $data['enable_ads_on_pharagraph'] : null;
	if ( ! $adscode ) {
		return $content;
	}
	$ads_code = isset( $data['single_pharagraph_adscode'] ) ? $data['single_pharagraph_adscode'] : '';
	$content = ms_insert_ads_to_pharagraph( $ads_code, $content );
	return $content;
}

add_filter("the_content", "ads_insertion");

/** custom excerpt */
function ms_custom_excerpt( $content, $post ) {
	global $data;
	$content_length = isset( $data['excerpt_content_length'] ) && ! empty( $data['excerpt_content_length'] ) ? intval( $data['excerpt_content_length'] ) : 200;
	$new_excerpt = substr( $content, 0, $content_length );
	$use_readmore = isset( $data['excerpt_use_readmore'] ) ? $data['excerpt_use_readmore'] : null;
	if ( ! empty( $use_readmore ) &&  ( $use_readmore == true || $use_readmore == "true" ) ) {
		$readmore_text = $data['excerpt_readmore_text'];
		if ( empty( $readmore_text ) ) {
			$readmore_text = "Read More..";
		}
		$new_excerpt .= sprintf('&nbsp;<a href="%s">%s</a>', get_the_permalink( $post->ID ), $readmore_text);
	}
	return $new_excerpt;
}
add_filter("get_the_excerpt", "ms_custom_excerpt", 10, 2);
/**
 * Custom meta */
/**
 * prevent duplicated posts
*/
$_post_id_array = array();