<?php

/**
 * Popular posts
**/

// prevent direct access
if( !defined( 'ABSPATH' ) ) {
	wp_die();
}

class ms_popular_posts_widgets extends WP_Widget {

	var $_custom_instance;

	/**
	 * set instance
	*/
	private function _custom_set_instance( $instance ) {
		if( !is_array() )
			return;

		$this->_custom_instance = $instance;
	}

	/**
	 * get instance
	*/
	private function _custom_get_instance() {
		return $this->_custom_instance;
	}

	/**
	 * constructor
	*/
	function __construct() {
		parent::__construct( false, 'Minisense: Popular post' );
	}

	/**
	 * form
	*/
	function form( $instance ) {
		$instance = wp_parse_args( ( array ) $instance, array(
						'posts_per_page' => 5,
						'exclude' => '',
						'post_title' => '1',
						'post_date' => '1',
						'post_excerpt' => '0',
						'post_readmore' => '0'
					) );

		/**
		 * set instance
		*/
		$this->_custom_set_instance( $instance );

		$form = array(
					array(
						'type' => 'text',
						'name' => 'posts_per_page',
						'label' => __( 'Posts per page ?' ),
						'desc' => __( 'Show how many posts will be posted in Popular posts' )
					), 
					array(
						'type' => 'multiselect',
						'name' => 'exclude',
						'label' => __( 'Exclude categories in:' ),
						'desc' => __( 'Select the categories will be filtered in Popular posts' ),
						'options' => ( $this->get_categories() ? ( array ) $this->get_categories : array( 'Uncategorized' ) )
					),
					array(
						'type' => 'select',
						'name' => 'post_title',
						'label' => __( 'Show post title ?' ),
						'options' => array(
										'0' => 'No',
										'1' => 'Yes'
									)
					),
					array(
						'type' => 'select',
						'name' => 'post_date',
						'label' => __( 'Show post date ?' ),
						'options' => array(
										'0' => 'No',
										'1' => 'Yes'
									)
					),
					array(
						'type' => 'select',
						'name' => 'post_excerpt',
						'label' => __( 'Show excerpt ?' ),
						'options' => array(
										'0' => 'No',
										'1' => 'Yes'
									)
					),
					array(
						'type' => 'text',
						'name' => 'post_readmore',
						'label' => 'Readmore label'
					)
				);

		foreach( $form as $input ) {

			// Show label
			$_label = !empty( $input['label'] ) ? $input['label'] : '';
			// Show Name
			$_name = !empty( $input['name'] ) ? $input['name'] : '';
			// Show description
			$_description = !empty( $input['desc'] ) ? $input['desc'] : '';
			// get value
			$_value = $instance[ $input['name'] ];

			switch( $input['type'] ) {

				case "text": ?>
					<p>
						<?php if( !empty( $_label ) ) { ?>
						<label for="<?php $this->get_field_name( $_name ); ?>"><?php echo $_label; ?></label><?php
						} ?>
						<input type="text" id="<?php echo $this->get_field_id( $_name ); ?>" class="widefat" name="<?php echo $this->get_field_name( $_name ); ?>" value="<?php echo $_value; ?>">
					</p><?php 
					break;

				case "select":

					if( !is_array( $input['options'] ) ) {
						break;
					} ?>
					<p>
						<?php if( !empty( $_label ) ) { ?>
						<label for="<?pp echo $this->get_field_name( $_name ); ?>"><?php echo $_label; ?></label><?php
						} ?>
						<select name="<?php echo $this->get_field_name( $_name ); ?>" class="widefat">
							<?php foreach( $input['options'] as $key => $val ) {
									$selected = $_value == $key ? ' selected="selected"' : ''; ?>
									<option value="<?php $key; ?>"<?php echo $selected; ?>><?php echo $val; ?></option>
							<?php } ?>
						</select>
					</p><?php 

					break;

				case "multiselect":

					if( !is_array( $input['options'] ) ) {
						break;
					} ?>
					<p>
						<?php if( !empty( $_label ) ) { ?>
						<label for="<?php echo $this->get_field_name( $_name ); ?>"><?php echo $_label; ?></label><?php
						} ?>

						<?php
						/**
						 * register data script
						*/ ?>
						<script type="text/javascript">
							var multidata<?php echo $this->get_field_id( $_name ); ?> = <?php echo json_encode( $input['options'] ); ?>;
						</script>

						<select name="<?php echo $this->get_field_name( $_name ); ?>" multi-data="<?php echo $this->get_field_id( $_name ); ?>" class="multiselect widefat">
							<?php foreach( $input['options'] as $key => $val ) {
									$selected = $_value == $key ? ' selected="selected"' : ''; ?>
									<option value="<?php echo $key; ?>"<?php echo $selected; ?>><?php echo $val; ?></option><?php
								}
							?>
						</select>
					</p><?php

					break;

			}
		}

	}

	/**
	 * update widgets
	*/
	function update( $new, $old ) {
		$instance = $old;

		// get instance
		$_instance = $this->_custom_get_instance();
		foreach( $_instance as $_instance_key => $_instance_val ) {
			$instance[ $_instance_key ] = $_instance_val;
		}

		return $instance;
	}

	/**
	 * widget callback
	*/
	function widget( $args, $instance ) {

		/**
		 * extract array into spices variable
		*/
		extract( $args );

		$loop_setting = $instance;
		$popular_loop_template = locate_template( get_stylesheet_directory() . '/loop/popular.php' );

		// echo the widgets args
		if( file_exists( $popular_loop_template ) ) {
			include( $popular_loop_template );
		}

	}

}

register_widget( "ms_popular_posts_widgets" );